@@ -32,6 +32,7 @@ class PrepID(CacheableBase):
                            endpoint='/couchdb/reqmgr_workload_cache/_design/ReqMgr/_view/byprepid?key="%s"' % (
                                self.prepID),
                            param='')
+        if data is None: return None
         rows = data['rows']
         workflows_s = [row['id'] for row in rows] # list of strings
         workflows = [Workflow(workflow) for workflow in workflows_s] # list of Workflow objects
@@ -63,6 +64,21 @@ class PrepID(CacheableBase):
         else:
             return self.getRecentWorkflowsMC()
 
+    def getRecentTasks(self):
+        """
+        :param None
+        :returns: the most recent task(s) under the given prepID. These tasks are the ones for which we need to
+                  take action, i.e. they are the ones for which no ACDC/recovery is created.
+                  For instance, if there is only one (original) workflow, then that should be returned.
+                  If there is one original, 3 ACDC0 and 2 ACDC1 and 2 ACDC2 workflows, then the 2 ACDC2s should be returned.
+        :rtype: list of tasks
+        """
+        originalWorkflow = self.getOriginalWorkflow()
+        if originalWorkflow.getRequestType() == 'ReReco':
+            return self.getRecentTasksReReco()
+        else:
+            return self.getRecentTasksMC()
+
     def getRecentWorkflowsMC(self):
         """
         :param None
@@ -86,6 +102,35 @@ class PrepID(CacheableBase):
 
         return recentWorkflows
 
+    def getRecentTasksMC(self):
+        """
+        :param None
+        :returns: the most recent task(s) under the given prepID. It covers the MC workflows
+        :rtype: list of tasks
+        """
+        workflows = self.getWorkflows()
+        activeWorkflows = self.removeRejectedWorkflows(workflows)
+
+        # get all tasks for active fworkflows
+        activeTasks = []
+        for wf in activeWorkflows:
+            activeTasks += wf.getTaskNames()
+
+        # Populate the parentTasks, i.e. the ones for which an ACDC/recovery is created
+        parentTaskNames = set()
+        for workflow in activeWorkflows:
+            parentTaskName = workflow.getParentTaskName()
+            if parentTaskName:
+                parentTaskNames.add(parentTaskName)
+
+        # recent tasks are defined to be the ones that have not been ACDC'd already
+        recentTasks = []
+        for task in activeTasks:
+            if task not in parentTaskNames:
+                recentTasks.append(task)
+
+        return recentTasks
+
     def getRecentWorkflowsReReco(self):
         """
         :param None
@@ -111,6 +156,31 @@ class PrepID(CacheableBase):
             # if youngest workflow is not a recovery, then regular MC function works
             return self.getRecentWorkflowsMC()
 
+    def getRecentTasksReReco(self):
+        """
+        :param None
+        :returns: the most recent workflow(s) under the given prepID. This function covers the special cases for ReReco
+                  workflows such as recovery workflows which are different from regular ACDCs.
+        :rtype: list of Workflow objects
+        """
+        recentWorkflows = []
+        youngestWorkflow = self.getYoungestWorkflow()
+        if youngestWorkflow.isRecovery():
+            # If the youngest workflow is a recovery, then return the latest recovery workflows
+            workflows = self.getWorkflows()
+            activeWorkflows = self.removeRejectedWorkflows(workflows)
+
+            for workflow in activeWorkflows:
+                if workflow.isRecovery():
+                    # A lazy workaround: Latest recovery workflows are submitted more or less  at the same time.
+                    # Here, we return all recovery workflows in a 1 hour time window based on the youngest one
+                    if youngestWorkflow.getAge() - workflow.getAge() < 3600:
+                        recentWorkflows.append(workflow)
+            return recentWorkflows
+        else:
+            # if youngest workflow is not a recovery, then regular MC function works
+            return self.getRecentTasksMC()
+
     def getLabels(self):
         """
         :param: None
