@@ -13,7 +13,7 @@ import time
 
 class Workflow(CacheableBase):
 
-    def __init__(self, workflowName, getUnreportedErrors=True, url='cmsweb.cern.ch'):
+    def __init__(self, workflowName, url='cmsweb.cern.ch'):
         """
         Initialize the Workflow class
         :param str workflowName: is the name of the workflow
@@ -74,12 +74,13 @@ class Workflow(CacheableBase):
 
         output = {}
 
-        ### FIMXE: check for each instead of harcoding
-        if 'StepChain' == self.requestType: identifier = 'Step'
-        elif 'TaskChain' == self.requestType: identifier = 'Task'
-        elif 'ReReco' == self.requestType: identifier = False
+        keys = self.workflowParams.keys()
+        if 'Step1' in keys: identifier = 'Step'
+        elif 'Task1' in keys: identifier = 'Task'
+        elif 'ReReco' == self.requestType or 'ReReco' == self.workflowParams['OriginalRequestType']: identifier = False
         else:
-            raise Exception("No steps or tasks found in this workflow.")
+            print("No Steps or Tasks found in this workflow and the requestType is not ReReco. RequestType: " + str(self.requestType))
+            return output
 
         # if MC
         if identifier:
@@ -140,7 +141,7 @@ class Workflow(CacheableBase):
                   they are the AgentJobInfo tasks.
         :rtype: list of str
         """
-        tasks = list(self.getJobStats().keys())
+        tasks = list(self.getErrors().keys())
         tasks = self.filterTaskNames(tasks)
 
         return tasks
@@ -333,10 +334,21 @@ class Workflow(CacheableBase):
         """
         :param None
         :returns: the ReqMgr status of the workflow
-        :rtype: string
+        :rtype: strings
         """
         return self.workflowParams["RequestStatus"]
 
+    def getParentTaskName(self):
+        """
+        :param None
+        :returns: the parent task. Parent task is the one for which the ACDC/recovery is created
+        :rtype: Workflow object
+        """
+        if 'InitialTaskPath' in self.workflowParams:
+            return self.workflowParams['InitialTaskPath']
+        else:
+            return None
+
     def getParentWorkflowName(self):
         """
         :param None
@@ -370,7 +382,9 @@ class Workflow(CacheableBase):
         else:
             return False
 
-    @cached_json('workflow_errors')
+    # Disable caching for now.
+    # TODO: We shouldn't need to change the source code to enable/disable caching. Make this configurable.
+    # @cached_json('workflow_errors')
     def getErrors(self, getUnreported=True):
         """
         Get the useful status information from a workflow
